@@ -15,7 +15,7 @@ class CategoryView(abstract_tab.Tab):
     }
 
     def __init__(self, config: Optional[Dict[str, Any]] = None):
-        super().__init__()
+        super().__init__(endpoints)
 
         if config is not None:
             self._config = config
