@@ -1,12 +1,12 @@
-from copy import deepcopy
-
-from typing import Optional, Dict, Any, List
+from typing import Union, Optional, Dict, Any, List
 
+from ai_dashboard.api import endpoints
 from ai_dashboard.tabs import abstract_tab
 from ai_dashboard.tabs.data_report import constants
 from ai_dashboard.tabs.data_report import aggregation_chart
 from ai_dashboard.tabs.data_report import metric
 from ai_dashboard.tabs.data_report import markdown
+from ai_dashboard.tabs.data_report import image
 
 
 class DataReport(abstract_tab.Tab):
@@ -22,6 +22,8 @@ class DataReport(abstract_tab.Tab):
 
     def __init__(
         self,
+        endpoints: endpoints.Endpoints,
+        dataset_id: str,
         title: str,
         name: Optional[str] = None,
         colour: Optional[str] = None,
@@ -29,6 +31,7 @@ class DataReport(abstract_tab.Tab):
     ):
         super().__init__()
 
+        self._endpoints = endpoints
         self.title = title
 
         if config is not None:
@@ -36,6 +39,8 @@ class DataReport(abstract_tab.Tab):
         else:
             self.reset()
 
+        self.dataset_id = dataset_id
+
         self.config["colour"] = colour.upper() if colour is not None else colour
         self.config["configuration"]["title"] = title
         self.config["name"] = name
@@ -108,6 +113,25 @@ class DataReport(abstract_tab.Tab):
         }
         return data_report
 
+    def insert_local_medias(self, file_paths: List[str]) -> List[str]:
+        presigned_urls = self._endpoints._get_file_upload_urls(
+            self.dataset_id,
+            files=file_paths,
+        )
+        urls = []
+        for index, file_path in enumerate(file_paths):
+            url = presigned_urls["files"][index]["url"]
+            upload_url = presigned_urls["files"][index]["upload_url"]
+            with open(file_path, "rb") as fn_byte:
+                media_content = bytes(fn_byte.read())
+            urls.append(url)
+            response = self._endpoints._upload_media(
+                presigned_url=upload_url,
+                media_content=media_content,
+            )
+            assert response.status_code == 200
+        return urls
+
     def add_markdown(self, text: str):
         md = markdown.MarkDown()
         content = md.parse(text)
@@ -152,3 +176,8 @@ class DataReport(abstract_tab.Tab):
             sort_direction=sort_direction,
         )
         self.config["configuration"]["content"]["content"] += chart
+
+    def add_image(self, image_src: str):
+        image_src = self.insert_local_medias([image_src])[0]
+        chart = image.image(image_src)
+        self.config["configuration"]["content"]["content"] += chart
